eclib: Enumerating and computing with elliptic curves defined over the rational numbers
=======================================================================================

Description
-----------

John Cremona's programs for enumerating and computing with elliptic curves
defined over the rational numbers.

mwrank is a program written in C++ for computing Mordell-Weil groups of
elliptic curves over Q via 2-descent. It is available as source code in
the eclib package, which may be distributed under the GNU General Public
License, version 2, or any later version.

mwrank is now only distributed as part of eclib. eclib is also included
in Sage, and for most potential users the easiest way to run mwrank is
to install Sage (which also of course gives you much much more). I no
longer provide a source code distribution of mwrank by itself: use eclib
instead.

License
-------

eclib is licensed GPL v2+.


Upstream Contact
----------------

-  Author: John Cremona
-  Email: john.cremona@gmail.com
-  Website:
   https://johncremona.github.io/mwrank/index.html
-  Repository: https://github.com/JohnCremona/eclib
